
# Type: jsonpointer

A string encoding a JSON Pointer. The value of the string MUST conform to JSON Point syntax and SHOULD dereference to a valid object within the current instance document when encoded in tree form.

URI: [linkml:Jsonpointer](https://w3id.org/linkml/Jsonpointer)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **str** |
| Representation | | str |
